#************************************************************ 
#
# Component       CNF  
#
# Synopsis        OpenBoot
#
#
# Copyright 2001-2004 Sun Microsystems, Inc. All rights reserved.
#
#
#************************************************************
#
# #ident "@(#)OBP.pm 1.8 04/03/12 SMI"
#
#************************************************************

package OBP ;

use strict;
use VAR;
use LOG ;
use CMM ;

#
#
#
my $G_category = "OBP" ;
my $G_load_done = "FALSE" ;

#
#  OBP related information
#
my $G_boot_device = "" ;
my $G_autoboot = "" ;
my $G_local_mac_address = "" ;
my $G_diag_switch = "";

#--------------------------------------------------------------
#
#  load
#
#      retrieve information related to boot
#
#--------------------------------------------------------------

sub load {

  if ($G_load_done eq "TRUE")
    {
      return ;
    }
  $G_load_done = "TRUE" ;
  
  # do not perform checking if eeprom is not accessible
  # (depends on the hardware platform)
  my $L_platform;
  LOG::printMsg(2,"    executing /usr/bin/uname -i...") ;
  chomp($L_platform = qx{/usr/bin/uname -i}) ;
  LOG::printMsg(2,"    -> platform: %s...", $L_platform) ;
  my $eeprom = "/usr/platform/$L_platform/sbin/eeprom";
  if (! -x $eeprom) {
    LOG::printWarning("eeprom not found for this hardware (%s)", 
		      $L_platform);
    return $FALSE;
  }
  
  #
  #  get the OBP configuration by running 'eeprom' utility
  #
  
  LOG::printMsg(2,"    executing %s...", $eeprom) ;
  my @L_result = qx{$eeprom} ;
  foreach my $L_line (@L_result)
    {
      chomp($L_line) ;
      LOG::printMsg(2,"    analyzing %s...", $L_line) ;
      if ( $L_line =~ /^boot-device=(.*)/o)
	{
	  $G_boot_device      = $1 ;
	  LOG::printMsg(2,"    -> Boot device: %s",  $G_boot_device) ;
	}
      if ( $L_line =~ /^auto-boot\?=([0-9a-z]*)/o)
	{
	  $G_autoboot         = $1 ;
	  LOG::printMsg(2,"    -> autoboot: %s", $G_autoboot) ;
	}
      if ( $L_line =~ /^local-mac-address\?=([0-9a-z]*)/o)
	{
	  $G_local_mac_address  = $1 ;
	  LOG::printMsg(2,"    -> local-mac-address: %s", 
			$G_local_mac_address) ;
	}
      if ( $L_line =~ /^diag-switch\?=([0-9a-z]*)/o)
	{
	  $G_diag_switch  = $1 ;
	  LOG::printMsg(2,"    -> diag-switch: %s", 
			$G_diag_switch) ;
	}
    }

  return $TRUE;
}

#--------------------------------------------------------------
#
#  check_configuration
#
#      check boot information in function of the node role
#
#--------------------------------------------------------------

sub check_configuration
  {
    LOG::printMsg(0, "") ;
    LOG::printMsg(0, "OBP checking") ;
    LOG::printMsg(0, "") ;

    if (! load) {
      return;
    }

    #
    #  check if the boot device type is valid for the node type
    #
    my $L_status = "OK" ;
    if ($E_variables{NODE_TYPE} ne "DISKLESS")
      {
	if ($G_boot_device !~ m/^[^\s\t]*disk/)
	  {
	    $L_status = "FAILED" ;
	  }
	LOG::printResult($L_status, "boot-device must look like 'disk'") ;
      }
    else
      {
	if ($G_boot_device !~ m/^(net:dhcp[0-9,]*[\s\t]*net2:dhcp[0-9,]*)/)
	  {
	    $L_status = "FAILED" ;
	  }
	LOG::printResult($L_status, 
			 "boot-device must look like 'net:dhcp net2:dhcp'") ;
      }

    #
    #  check if OBP is set in auto reboot mode
    #
    $L_status = "OK" ;
    if ($G_autoboot ne "true")
      {
	$L_status = "FAILED" ;
      }
    LOG::printResult($L_status, "auto-boot must be set to 'true'") ;

    #
    #  check if local mac address is set to true
    #
    $L_status = "OK" ;
    if ($G_local_mac_address ne "true")
      {
	$L_status = "FAILED" ;
      }
    LOG::printResult($L_status, "local-mac-address must be set to 'true'") ;

    #
    #  check if diag-switch is set to false
    #
    $L_status = "OK" ;
    if ($G_diag_switch ne "false")
      {
	$L_status = "FAILED" ;
      }
    LOG::printResult($L_status, "diag-switch must be set to 'false'") ;
  }

#--------------------------------------------------------------
#
#  main
#
#--------------------------------------------------------------

{
}
